==> tencent_im_sdk_plugin_web-0.0.1.tar.gz: lib/src/manager/v2_tim_conversation_manager.dart <==
import 'package:js/js.dart';
import 'package:js/js_util.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/enum/V2TimConversationListener.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/models/v2_tim_conversation_result.dart';
import 'package:tencent_im_sdk_plugin_web/src/manager/im_sdk_plugin_js.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_delete_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_get_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_get_conversation_list.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_pin_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/utils/utils.dart';

class V2TIMConversationManager {
  late TIM? timeweb;

  V2TIMConversationManager() {
    timeweb = V2TIMManagerWeb.timWeb;
  }

/*
  注意：web只有一个update回调(新增也在里面)，这个回调不做初始化磨平操作，native有新的会话
  即会在初始化时调用这个监听
*/
  void setConversationListener(V2TimConversationListener listener) async {
    timeweb!.on("onConversationListUpdated", allowInterop((res) async {
      List<dynamic> conversationList =
          await GetConversationList.formateConversationList(res.data);
      final convList =
          conversationList.map((e) => V2TimConversation.fromJson(e)).toList();
      listener.onConversationChanged(convList);
    }));
  }

  void makeConversationListenerEventData(_channel, String type, data) {
    CommonUtils.emitEvent(_channel, "conversationListener", type, data);
  }

  // web 中参数无法传递分页信息
  Future<dynamic> getConversationList() async {
    print("web中nextSeq，count等分页参数不生效");
    try {
      final res = await promiseToFuture(timeweb!.getConversationList());

      List<dynamic> conversationList =
          await GetConversationList.formateConversationList(
              res.data.conversationList);
      return CommonUtils.returnSuccess<V2TimConversationResult>(
          GetConversationList.formatReturn(conversationList));
    } catch (error) {
      return CommonUtils.returnErrorForValueCb<V2TimConversationResult>(
          error.toString());
    }
  }

  // 和getConversationList 调用的是相同的方法, 此项接口返回的数据没有getConversationProfile全
  Future<dynamic> getConversationListByConversaionIds(param) async {
    try {
      var res = await promiseToFuture(
          timeweb!.getConversationList(param["conversationIDList"]));
      var conversationList = await GetConversationList.formateConversationList(
          res.data.conversationList);
      return CommonUtils.returnSuccess<List<V2TimConversation>>(
          conversationList);
    } catch (err) {
      return CommonUtils.returnErrorForValueCb<List<V2TimConversation>>(err);
    }
  }

  // web中的方法名字是： getConversationProfile
  Future<dynamic> getConversation(conversationParams) async {
    try {
      var res = await promiseToFuture(timeweb!.getConversationProfile(
          GetConversation.formateParams(conversationParams)));

      return CommonUtils.returnSuccess<V2TimConversation>(
          await GetConversationList.formateConversationListItem(
              res.data.conversation));
    } catch (err) {
      return CommonUtils.returnErrorForValueCb<V2TimConversation>(err);
    }
  }

  Future<dynamic> deleteConversation(conversationParams) async {
    try {
      final res = await promiseToFuture(timeweb!.deleteConversation(
          DeleteConversation.formateParams(conversationParams)));

      return CommonUtils.returnSuccessWithDesc('ok');
    } catch (err) {
      return CommonUtils.returnError(err.toString());
    }
  }

  Future<dynamic> pinConversation(params) async {
    try {
      final formatedParams = PinConversation.formateParams(params);
      final res =
          await promiseToFuture(timeweb!.pinConversation(formatedParams));
      return CommonUtils.returnSuccessForCb(res.conversationID);
    } catch (err) {
      return CommonUtils.returnError(err);
    }
  }

  // web不存在添加草稿功能
  Future<dynamic> setConversationDraft() async {
    print("web不支持添加草稿功能");
    return CommonUtils.returnError(
        "setConversationDraft feature does not exist on the web");
  }

  // web不存在获得未读消息总数此功能
  Future<dynamic> getTotalUnreadMessageCount() async {
    print("web不支持获得未读消息总数此功能");
    return CommonUtils.returnErrorForValueCb<int>(
        "getTotalUnreadMessageCount feature does not exist on the web");
  }
}

==> tencent_im_sdk_plugin_web-0.0.5.tar.gz: lib/src/manager/v2_tim_conversation_manager.dart <==
import 'package:js/js.dart';
import 'package:js/js_util.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/enum/V2TimConversationListener.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/models/v2_tim_conversation.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/models/v2_tim_conversation_result.dart';
import 'package:tencent_im_sdk_plugin_platform_interface/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin_web/src/manager/im_sdk_plugin_js.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_delete_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_get_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_get_conversation_list.dart';
import 'package:tencent_im_sdk_plugin_web/src/models/v2_tim_pin_conversation.dart';
import 'package:tencent_im_sdk_plugin_web/src/utils/utils.dart';

class V2TIMConversationManager {
  late TIM? timeweb;

  V2TIMConversationManager() {
    timeweb = V2TIMManagerWeb.timWeb;
  }

/*
  注意：web只有一个update回调(新增也在里面)，这个回调不做初始化磨平操作，native有新的会话
  即会在初始化时调用这个监听
*/
  void setConversationListener(V2TimConversationListener listener) async {
    timeweb!.on("onConversationListUpdated", allowInterop((res) async {
      List<dynamic> conversationList =
          await GetConversationList.formateConversationList(
              jsToMap(res)['data']);
      final convList =
          conversationList.map((e) => V2TimConversation.fromJson(e)).toList();
      listener.onConversationChanged(convList);
    }));
  }

  void makeConversationListenerEventData(_channel, String type, data) {
    CommonUtils.emitEvent(_channel, "conversationListener", type, data);
  }

  // web 中参数无法传递分页信息
  Future<V2TimValueCallback<V2TimConversationResult>>
      getConversationList() async {
    // try {
    final res = await wrappedPromiseToFuture(timeweb!.getConversationList());
    List<dynamic> conversationList =
        await GetConversationList.formateConversationList(
            jsToMap(res.data)['conversationList']);
    return CommonUtils.returnSuccess<V2TimConversationResult>(
        GetConversationList.formatReturn(conversationList));
    // } catch (error) {
    //   return CommonUtils.returnErrorForValueCb<V2TimConversationResult>(
    //       error.toString());
    // }
  }

  // 和getConversationList 调用的是相同的方法, 此项接口返回的数据没有getConversationProfile全
  Future<dynamic> getConversationListByConversaionIds(param) async {
    try {
      var res = await wrappedPromiseToFuture(
          timeweb!.getConversationList(param["conversationIDList"]));
      var conversationList = await GetConversationList.formateConversationList(
          jsToMap(res.data)['conversationList']);
      return CommonUtils.returnSuccess<List<V2TimConversation>>(
          conversationList);
    } catch (err) {
      return CommonUtils.returnErrorForValueCb<List<V2TimConversation>>(err);
    }
  }

  // web中的方法名字是： getConversationProfile
  Future<dynamic> getConversation(conversationParams) async {
    try {
      var res = await wrappedPromiseToFuture(timeweb!.getConversationProfile(
          GetConversation.formateParams(conversationParams)));

      return CommonUtils.returnSuccess<V2TimConversation>(
          await GetConversationList.formateConversationListItem(
              jsToMap(jsToMap(res.data)['conversation'])));
    } catch (err) {
      return CommonUtils.returnErrorForValueCb<V2TimConversation>(err);
    }
  }

  Future<dynamic> deleteConversation(conversationParams) async {
    try {
      final res = await promiseToFuture(timeweb!.deleteConversation(
          DeleteConversation.formateParams(conversationParams)));

      return CommonUtils.returnSuccessWithDesc('ok');
    } catch (err) {
      return CommonUtils.returnError(err.toString());
    }
  }

  Future<dynamic> pinConversation(params) async {
    try {
      final formatedParams = PinConversation.formateParams(params);
      final res =
          await promiseToFuture(timeweb!.pinConversation(formatedParams));
      return CommonUtils.returnSuccessForCb(jsToMap(res)['conversationID']);
    } catch (err) {
      return CommonUtils.returnError(err);
    }
  }

  // web不存在添加草稿功能
  Future<dynamic> setConversationDraft() async {
    print("web不支持添加草稿功能");
    return CommonUtils.returnError(
        "setConversationDraft feature does not exist on the web");
  }

  // web不存在获得未读消息总数此功能
  Future<dynamic> getTotalUnreadMessageCount() async {
    print("web不支持获得未读消息总数此功能");
    return CommonUtils.returnErrorForValueCb<int>(
        "getTotalUnreadMessageCount feature does not exist on the web");
  }
}
